@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# 密钥不合法。
+AUTHFAILURE_ACCESSKEYILLEGAL = 'AuthFailure.AccessKeyIllegal'
+
 # DB错误。
 INTERNALERROR_DBERROR = 'InternalError.DbError'
 
@@ -35,12 +38,15 @@ INTERNALERROR_ILLEGALROLE = 'InternalError.IllegalRole'
 # pb打包失败。
 INTERNALERROR_PBSERIALIZEERROR = 'InternalError.PbSerializeError'
 
-# 内部错误。
+# 系统内部错误，如网络错误。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
 # 未知错误。
 INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
 
+# 不支持该类型密钥。
+INVALIDPARAMETER_ACCESSKEYNOTSUPPORT = 'InvalidParameter.AccessKeyNotSupport'
+
 # 账号不存在或不可用。
 INVALIDPARAMETER_ACCOUNTNOTAVALIABLE = 'InvalidParameter.AccountNotAvaliable'
 
@@ -62,7 +68,7 @@ INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 # 策略过长。
 INVALIDPARAMETER_POLICYTOOLONG = 'InvalidParameter.PolicyTooLong'
 
-# 资源错误。
+# 策略资源六段式错误。
 INVALIDPARAMETER_RESOUCEERROR = 'InvalidParameter.ResouceError'
 
 # 策略语法错误。
@@ -71,7 +77,7 @@ INVALIDPARAMETER_STRATEGYFORMATERROR = 'InvalidParameter.StrategyFormatError'
 # 非法策略。
 INVALIDPARAMETER_STRATEGYINVALID = 'InvalidParameter.StrategyInvalid'
 
-# TCB temp code 无效。
+# 临时Code无效。
 INVALIDPARAMETER_TEMPCODENOTAVALIABLE = 'InvalidParameter.TempCodeNotAvaliable'
 
 # 账号对应的角色不存在。
